@@ -1120,7 +1120,7 @@ static void eval_status(struct bfs_eval *state, struct bfs_bar *bar, struct time
 	const struct BFTW *ftwbuf = state->ftwbuf;
 
 	dchar *status = NULL;
-	dchar *rhs = dstrprintf(" (visited: %'zu, depth: %2zu)", count, ftwbuf->depth);
+	dchar *rhs = dstrprintf(" (visited: %'zu; depth: %2zu)", count, ftwbuf->depth);
 	if (!rhs) {
 		return;
 	}
